# Impractipy - A Collection of Impractical Python Projects

This project includes a number of packages that are impractical. As I follow along Lee Vaughan's book "Impractical Python Projects", I decided to store the exercises within a git repository, both as a way to reference them later, but also to get some practice with publishing a PyPi package.

The first many of these will more than likely be directly from the book. Eventually, I'd like to make up some of my own.

# Projects

## Pseudonyms

This function lets you generate silly names.
